CloseableLocalServerHandler

Trait CloseableLocalServerHandler 

pub trait CloseableLocalServerHandler<___T = Channel>
where ___T: Transport,
{ // Required method fn close( &mut self, responder: Responder<Close, ___T>, ) -> impl Future<Output = ()>; }
A server handler for the Closeable protocol.

See Closeable for more details.

Required Methods

fn close( &mut self, responder: Responder<Close, ___T>, ) -> impl Future<Output = ()>

Terminates the connection.

After calling Close, the client must not send any other requests.

Servers, after sending the status response, should close the connection regardless of status and without sending an epitaph.

Closing the client end of the channel should be semantically equivalent to calling Close without knowing when the close has completed or its status.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<___H, ___T> CloseableLocalServerHandler<___T> for Local<___H>
where ___H: CloseableServerHandler<___T>, ___T: Transport,

Source

async fn close(&mut self, responder: Responder<Close, ___T>)

Implementors